# Anam plugin for LiveKit Agents

Support for the [Anam](https://anam.ai/) virtual avatar.

See the [Anam integration docs](https://docs.livekit.io/agents/models/avatar/plugins/anam/) for more information.

## Installation

```bash
pip install livekit-plugins-anam
```

## Pre-requisites

You'll need an API key from Anam. It can be set as an environment variable: `ANAM_API_KEY`
